@@ -500,7 +500,7 @@ typedef enum {
 
 // T is rgba if and only if it has an T::r field.
 template<typename T, typename = void> struct is_grayscale : std::true_type {};
-template<typename T> struct is_grayscale<T, decltype(T::r, void())> : std::false_type {};
+template<typename T> struct is_grayscale<T, std::void_t<decltype(T::r)>> : std::false_type {};
 
 
 template<typename color_type>
